package cn.rankin.cmsweb.controller.stmt;

import cn.rankin.cmsweb.assist.resolver.NeedUser;
import cn.rankin.cmsweb.entity.UserDetails;
import cn.rankin.cmsweb.service.stmt.StmtCampusService;
import cn.rankin.cmsweb.service.user.TerminalUserService;
import cn.rankin.common.utils.api.model.APIResult;
import cn.rankin.common.utils.api.page.Page;
import cn.rankin.common.utils.util.BeanUtil;
import cn.rankin.data.api.user.dto.CampusSearchDTO;
import cn.rankin.data.api.user.dto.TerminalUserSearchDTO;
import cn.rankin.data.api.user.vo.CampusVo;
import cn.rankin.data.api.user.vo.TerminalUserAuthVo;
import cn.rankin.data.api.user.vo.TerminalUserVo;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;


@Slf4j
@RestController
@RequestMapping(value = "/stmt/stats")
public class StmtStatsController
{
    @Autowired
    private TerminalUserService terminalUserService;

    @Autowired
    private StmtCampusService stmtService;

    /**
     * 获取终端明细
     *
     * @param user      the user details
     * @param searchDTO the search Dto
     * @return
     */
    @RequestMapping(value = {"/page", "/"}, method = RequestMethod.GET)
    public APIResult<Page<TerminalUserVo>> campusList(@NeedUser UserDetails user, TerminalUserSearchDTO searchDTO)
    {
        if (!user.isPlatForm())
        {
            String merchantId = user.getMerchantId();
            searchDTO.setMerchantId(merchantId);
        }
        APIResult<Page<TerminalUserVo>> page = terminalUserService.search(BeanUtil.convertToMap(searchDTO));

        return page;
    }

    /**
     * 获取校区总数
     *
     * @param user            the user details
     * @param campusSearchDTO the search Dto
     * @return
     */
    @RequestMapping(value = {"/campus/totalsize", "/"}, method = RequestMethod.GET)
    public APIResult<Page<CampusVo>> getCampusTotalSize(@NeedUser UserDetails user, CampusSearchDTO campusSearchDTO)
    {
        if (!user.isPlatForm())
        {
            String merchantId = user.getMerchantId();
            campusSearchDTO.setMerchantId(merchantId);
        }
        APIResult<Page<CampusVo>> pageData = stmtService.search(BeanUtil.convertToMap(campusSearchDTO));

        return APIResult.ok(pageData.getData().getTotalSize());
    }

    /**
     * 获取终端用户数
     *
     * @param user the user details
     * @param dto  the search Dto
     * @return
     */
    @RequestMapping(value = {"/terminal/user/totalsize", "/"}, method = RequestMethod.GET)
    public APIResult<Page<TerminalUserAuthVo>> getTerminalTotalSize(@NeedUser UserDetails user, TerminalUserSearchDTO dto)
    {
        if (!user.isPlatForm())
        {
            String merchantId = user.getMerchantId();
            dto.setMerchantId(merchantId);
        }

        APIResult<Page<TerminalUserVo>> pageData =  terminalUserService.search(BeanUtil.convertToMap(dto));

        if (pageData != null)
        {
            return APIResult.ok(pageData.getData().getTotalSize());
        }
        else
        {
            return APIResult.ok(0);
        }
    }
}
